Implicit ODE methods for stiff systems.
Functions
- detect_
stiffness - Detects whether the problem is stiff using a heuristic.
- implicit_
euler - Backward Euler method for stiff ODEs.
- solve_
implicit - Chooses between explicit and implicit methods based on stiffness detection.
- trbdf2
- TR-BDF2 method: two-stage implicit method combining trapezoidal rule with BDF2.